# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from instana_client.models.bidirectional_ms_teams_app_integration import BidirectionalMsTeamsAppIntegration
    from instana_client.models.bidirectional_slack_app_integration import BidirectionalSlackAppIntegration
    from instana_client.models.email_integration import EmailIntegration
    from instana_client.models.google_chat_integration import GoogleChatIntegration
    from instana_client.models.office365_integration import Office365Integration
    from instana_client.models.opsgenie_integration import OpsgenieIntegration
    from instana_client.models.pagerduty_integration import PagerdutyIntegration
    from instana_client.models.prometheus_webhook_integration import PrometheusWebhookIntegration
    from instana_client.models.salesforce_integration import SalesforceIntegration
    from instana_client.models.service_now_enhanced_integration import ServiceNowEnhancedIntegration
    from instana_client.models.service_now_integration import ServiceNowIntegration
    from instana_client.models.slack_integration import SlackIntegration
    from instana_client.models.splunk_integration import SplunkIntegration
    from instana_client.models.victor_ops_integration import VictorOpsIntegration
    from instana_client.models.watson_ai_ops_webhook_integration import WatsonAIOpsWebhookIntegration
    from instana_client.models.webex_teams_webhook_integration import WebexTeamsWebhookIntegration
    from instana_client.models.webhook_integration import WebhookIntegration
    from instana_client.models.z_chat_ops_integration import ZChatOpsIntegration

class AbstractIntegration(BaseModel):
    """
    AbstractIntegration
    """ # noqa: E501
    id: StrictStr = Field(description="Unique ID of the returned Alert Channel")
    kind: StrictStr = Field(description="The type of the Alerting Channel.")
    name: StrictStr = Field(description="The name of the Alerting Channel.")
    __properties: ClassVar[List[str]] = ["id", "kind", "name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'kind'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        'BIDIRECTIONAL_MS_TEAMS': 'BidirectionalMsTeamsAppIntegration','BIDIRECTIONAL_SLACK': 'BidirectionalSlackAppIntegration','EMAIL': 'EmailIntegration','GOOGLE_CHAT': 'GoogleChatIntegration','OFFICE_365': 'Office365Integration','OPS_GENIE': 'OpsgenieIntegration','PAGER_DUTY': 'PagerdutyIntegration','PROMETHEUS_WEBHOOK': 'PrometheusWebhookIntegration','SALESFORCE': 'SalesforceIntegration','SERVICE_NOW_APPLICATION': 'ServiceNowEnhancedIntegration','SERVICE_NOW_WEBHOOK': 'ServiceNowIntegration','SLACK': 'SlackIntegration','SPLUNK': 'SplunkIntegration','VICTOR_OPS': 'VictorOpsIntegration','WATSON_AIOPS_WEBHOOK': 'WatsonAIOpsWebhookIntegration','WEBEX_TEAMS_WEBHOOK': 'WebexTeamsWebhookIntegration','WEB_HOOK': 'WebhookIntegration','Z_CHATOPS': 'ZChatOpsIntegration'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[BidirectionalMsTeamsAppIntegration, BidirectionalSlackAppIntegration, EmailIntegration, GoogleChatIntegration, Office365Integration, OpsgenieIntegration, PagerdutyIntegration, PrometheusWebhookIntegration, SalesforceIntegration, ServiceNowEnhancedIntegration, ServiceNowIntegration, SlackIntegration, SplunkIntegration, VictorOpsIntegration, WatsonAIOpsWebhookIntegration, WebexTeamsWebhookIntegration, WebhookIntegration, ZChatOpsIntegration]]:
        """Create an instance of AbstractIntegration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[BidirectionalMsTeamsAppIntegration, BidirectionalSlackAppIntegration, EmailIntegration, GoogleChatIntegration, Office365Integration, OpsgenieIntegration, PagerdutyIntegration, PrometheusWebhookIntegration, SalesforceIntegration, ServiceNowEnhancedIntegration, ServiceNowIntegration, SlackIntegration, SplunkIntegration, VictorOpsIntegration, WatsonAIOpsWebhookIntegration, WebexTeamsWebhookIntegration, WebhookIntegration, ZChatOpsIntegration]]:
        """Create an instance of AbstractIntegration from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type ==  'BidirectionalMsTeamsAppIntegration':
            return import_module("instana_client.models.bidirectional_ms_teams_app_integration").BidirectionalMsTeamsAppIntegration.from_dict(obj)
        if object_type ==  'BidirectionalSlackAppIntegration':
            return import_module("instana_client.models.bidirectional_slack_app_integration").BidirectionalSlackAppIntegration.from_dict(obj)
        if object_type ==  'EmailIntegration':
            return import_module("instana_client.models.email_integration").EmailIntegration.from_dict(obj)
        if object_type ==  'GoogleChatIntegration':
            return import_module("instana_client.models.google_chat_integration").GoogleChatIntegration.from_dict(obj)
        if object_type ==  'Office365Integration':
            return import_module("instana_client.models.office365_integration").Office365Integration.from_dict(obj)
        if object_type ==  'OpsgenieIntegration':
            return import_module("instana_client.models.opsgenie_integration").OpsgenieIntegration.from_dict(obj)
        if object_type ==  'PagerdutyIntegration':
            return import_module("instana_client.models.pagerduty_integration").PagerdutyIntegration.from_dict(obj)
        if object_type ==  'PrometheusWebhookIntegration':
            return import_module("instana_client.models.prometheus_webhook_integration").PrometheusWebhookIntegration.from_dict(obj)
        if object_type ==  'SalesforceIntegration':
            return import_module("instana_client.models.salesforce_integration").SalesforceIntegration.from_dict(obj)
        if object_type ==  'ServiceNowEnhancedIntegration':
            return import_module("instana_client.models.service_now_enhanced_integration").ServiceNowEnhancedIntegration.from_dict(obj)
        if object_type ==  'ServiceNowIntegration':
            return import_module("instana_client.models.service_now_integration").ServiceNowIntegration.from_dict(obj)
        if object_type ==  'SlackIntegration':
            return import_module("instana_client.models.slack_integration").SlackIntegration.from_dict(obj)
        if object_type ==  'SplunkIntegration':
            return import_module("instana_client.models.splunk_integration").SplunkIntegration.from_dict(obj)
        if object_type ==  'VictorOpsIntegration':
            return import_module("instana_client.models.victor_ops_integration").VictorOpsIntegration.from_dict(obj)
        if object_type ==  'WatsonAIOpsWebhookIntegration':
            return import_module("instana_client.models.watson_ai_ops_webhook_integration").WatsonAIOpsWebhookIntegration.from_dict(obj)
        if object_type ==  'WebexTeamsWebhookIntegration':
            return import_module("instana_client.models.webex_teams_webhook_integration").WebexTeamsWebhookIntegration.from_dict(obj)
        if object_type ==  'WebhookIntegration':
            return import_module("instana_client.models.webhook_integration").WebhookIntegration.from_dict(obj)
        if object_type ==  'ZChatOpsIntegration':
            return import_module("instana_client.models.z_chat_ops_integration").ZChatOpsIntegration.from_dict(obj)

        raise ValueError("AbstractIntegration failed to lookup discriminator value from " +
                            json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                            ", mapping: " + json.dumps(cls.__discriminator_value_class_map))





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.dns_configuration import DNSConfiguration

class TestDNSConfiguration(unittest.TestCase):
    """DNSConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DNSConfiguration:
        """Test DNSConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DNSConfiguration`
        """
        model = DNSConfiguration()
        if include_optional:
            return DNSConfiguration(
                accept_cname = True,
                lookup = '',
                lookup_server_name = True,
                port = 56,
                query_time = instana_client.models.dns_filter_query_time.DNSFilterQueryTime(
                    key = '', 
                    operator = 'CONTAINS', 
                    value = 56, ),
                query_type = 'ALL',
                recursive_lookups = True,
                server = '',
                server_retries = 56,
                target_values = [
                    instana_client.models.dns_filter_target_value.DNSFilterTargetValue(
                        key = 'ALL', 
                        operator = 'CONTAINS', 
                        value = '', )
                    ],
                transport = 'TCP'
            )
        else:
            return DNSConfiguration(
                lookup = '',
                server = '',
        )
        """

    def testDNSConfiguration(self):
        """Test DNSConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_settings_api import SyntheticSettingsApi


class TestSyntheticSettingsApi(unittest.TestCase):
    """SyntheticSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_synthetic_credential(self) -> None:
        """Test case for create_synthetic_credential

        Create a Synthetic credential
        """
        pass

    def test_create_synthetic_test(self) -> None:
        """Test case for create_synthetic_test

        Create a Synthetic test
        """
        pass

    def test_create_synthetic_test_cicd(self) -> None:
        """Test case for create_synthetic_test_cicd

        Create a Synthetic test CI/CD
        """
        pass

    def test_delete_synthetic_credential(self) -> None:
        """Test case for delete_synthetic_credential

        Delete a Synthetic credential
        """
        pass

    def test_delete_synthetic_location(self) -> None:
        """Test case for delete_synthetic_location

        Delete a Synthetic location
        """
        pass

    def test_delete_synthetic_test(self) -> None:
        """Test case for delete_synthetic_test

        Delete a Synthetic test
        """
        pass

    def test_get_one_synthetic_credential_associations(self) -> None:
        """Test case for get_one_synthetic_credential_associations

        A Synthetic credential
        """
        pass

    def test_get_synthetic_credential_associations(self) -> None:
        """Test case for get_synthetic_credential_associations

        All Synthetic credentials
        """
        pass

    def test_get_synthetic_credential_names(self) -> None:
        """Test case for get_synthetic_credential_names

        All Synthetic credential names
        """
        pass

    def test_get_synthetic_datacenter(self) -> None:
        """Test case for get_synthetic_datacenter

        A Synthetic datacenter
        """
        pass

    def test_get_synthetic_datacenters(self) -> None:
        """Test case for get_synthetic_datacenters

        All Synthetic datacenters
        """
        pass

    def test_get_synthetic_location(self) -> None:
        """Test case for get_synthetic_location

        A Synthetic location
        """
        pass

    def test_get_synthetic_locations(self) -> None:
        """Test case for get_synthetic_locations

        All Synthetic locations
        """
        pass

    def test_get_synthetic_test(self) -> None:
        """Test case for get_synthetic_test

        A Synthetic test
        """
        pass

    def test_get_synthetic_test_cicd(self) -> None:
        """Test case for get_synthetic_test_cicd

        A Synthetic test CI/CD.
        """
        pass

    def test_get_synthetic_test_cicds(self) -> None:
        """Test case for get_synthetic_test_cicds

        All Synthetic test CI/CDs
        """
        pass

    def test_get_synthetic_tests(self) -> None:
        """Test case for get_synthetic_tests

        All Synthetic tests
        """
        pass

    def test_patch_synthetic_credential(self) -> None:
        """Test case for patch_synthetic_credential

        Patch a Synthetic credential
        """
        pass

    def test_patch_synthetic_test(self) -> None:
        """Test case for patch_synthetic_test

        Patch a Synthetic test
        """
        pass

    def test_update_synthetic_credential(self) -> None:
        """Test case for update_synthetic_credential

        Update a Synthetic credential
        """
        pass

    def test_update_synthetic_test(self) -> None:
        """Test case for update_synthetic_test

        Update a Synthetic test
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.api_team import ApiTeam

class TestApiTeam(unittest.TestCase):
    """ApiTeam unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiTeam:
        """Test ApiTeam
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiTeam`
        """
        model = ApiTeam()
        if include_optional:
            return ApiTeam(
                id = '',
                info = instana_client.models.api_team_info.ApiTeamInfo(
                    description = '', ),
                members = [
                    instana_client.models.api_team_member.ApiTeamMember(
                        email = '', 
                        name = '', 
                        roles = [
                            instana_client.models.api_team_role.ApiTeamRole(
                                role_id = '', 
                                role_name = '', 
                                via_id_p = True, )
                            ], 
                        user_id = '', )
                    ],
                scope = instana_client.models.api_team_scope.ApiTeamScope(
                    access_permissions = [
                        'LIMITED_APPLICATIONS_SCOPE'
                        ], 
                    action_filter = '', 
                    applications = [
                        ''
                        ], 
                    business_perspectives = [
                        ''
                        ], 
                    infra_dfq_filter = '', 
                    kubernetes_clusters = [
                        ''
                        ], 
                    kubernetes_namespaces = [
                        ''
                        ], 
                    log_filter = '', 
                    mobile_apps = [
                        ''
                        ], 
                    restricted_application_filter = instana_client.models.api_restricted_application_filter.ApiRestrictedApplicationFilter(
                        label = '', 
                        restricting_application_id = '', 
                        scope = 'INCLUDE_NO_DOWNSTREAM', 
                        tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                            type = '', ), ), 
                    slo_ids = [
                        ''
                        ], 
                    synthetic_credentials = [
                        ''
                        ], 
                    synthetic_tests = [
                        ''
                        ], 
                    tag_ids = [
                        ''
                        ], 
                    websites = [
                        ''
                        ], ),
                tag = ''
            )
        else:
            return ApiTeam(
                tag = '',
        )
        """

    def testApiTeam(self):
        """Test ApiTeam"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.releases_api import ReleasesApi


class TestReleasesApi(unittest.TestCase):
    """ReleasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReleasesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_release(self) -> None:
        """Test case for delete_release

        Delete release
        """
        pass

    def test_get_all_releases(self) -> None:
        """Test case for get_all_releases

        Get all releases
        """
        pass

    def test_get_release(self) -> None:
        """Test case for get_release

        Get release
        """
        pass

    def test_post_release(self) -> None:
        """Test case for post_release

        Create release
        """
        pass

    def test_put_release(self) -> None:
        """Test case for put_release

        Update release
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_topology_api import InfrastructureTopologyApi


class TestInfrastructureTopologyApi(unittest.TestCase):
    """InfrastructureTopologyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureTopologyApi()

    def tearDown(self) -> None:
        pass

    def test_get_related_hosts(self) -> None:
        """Test case for get_related_hosts

        Related hosts
        """
        pass

    def test_get_topology(self) -> None:
        """Test case for get_topology

        Gets the infrastructure topology
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.mobile_app_configuration_api import MobileAppConfigurationApi


class TestMobileAppConfigurationApi(unittest.TestCase):
    """MobileAppConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MobileAppConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_clear_mobile_app_source_map_upload_configuration(self) -> None:
        """Test case for clear_mobile_app_source_map_upload_configuration

        Clear sourcemap files for sourcemap upload configuration
        """
        pass

    def test_commit_mobile_app_source_map_file(self) -> None:
        """Test case for commit_mobile_app_source_map_file

        Commit sourcemap file upload for mobile app
        """
        pass

    def test_delete_mobile_app_config(self) -> None:
        """Test case for delete_mobile_app_config

        Remove mobile app
        """
        pass

    def test_delete_mobile_app_source_map_upload_configuration(self) -> None:
        """Test case for delete_mobile_app_source_map_upload_configuration

        Delete sourcemap configuration for mobile app
        """
        pass

    def test_get_mobile_app_config(self) -> None:
        """Test case for get_mobile_app_config

        Get configured mobile apps
        """
        pass

    def test_get_mobile_app_geo_location_configuration(self) -> None:
        """Test case for get_mobile_app_geo_location_configuration

        Get geo location configuration for mobile app
        """
        pass

    def test_get_mobile_app_geo_mapping_rules(self) -> None:
        """Test case for get_mobile_app_geo_mapping_rules

        Get custom geo mapping rules for mobile app
        """
        pass

    def test_get_mobile_app_ip_masking_configuration(self) -> None:
        """Test case for get_mobile_app_ip_masking_configuration

        Get IP masking configuration for mobile app
        """
        pass

    def test_get_mobile_app_source_map_file(self) -> None:
        """Test case for get_mobile_app_source_map_file

        Get sourcemap configuration for mobile app
        """
        pass

    def test_get_mobile_app_source_map_files(self) -> None:
        """Test case for get_mobile_app_source_map_files

        Get all sourcemap configurations for mobile app
        """
        pass

    def test_get_single_mobile_app_config(self) -> None:
        """Test case for get_single_mobile_app_config

        Get mobile app configuration by ID
        """
        pass

    def test_post_mobile_app_config(self) -> None:
        """Test case for post_mobile_app_config

        Configure new mobile app
        """
        pass

    def test_post_mobile_app_source_map_config(self) -> None:
        """Test case for post_mobile_app_source_map_config

        Add new sourcemap configuration for mobile app
        """
        pass

    def test_rename_mobile_app_config(self) -> None:
        """Test case for rename_mobile_app_config

        Rename mobile app
        """
        pass

    def test_set_mobile_app_geo_mapping_rules(self) -> None:
        """Test case for set_mobile_app_geo_mapping_rules

        Set custom geo mapping rules for mobile app
        """
        pass

    def test_update_mobile_app_geo_location_configuration(self) -> None:
        """Test case for update_mobile_app_geo_location_configuration

        Update geo location configuration for mobile app
        """
        pass

    def test_update_mobile_app_ip_masking_configuration(self) -> None:
        """Test case for update_mobile_app_ip_masking_configuration

        Update IP masking configuration for mobile app
        """
        pass

    def test_update_mobile_app_teams(self) -> None:
        """Test case for update_mobile_app_teams

        Update teams assigned to the mobile app
        """
        pass

    def test_upload_mobile_app_source_map_file(self) -> None:
        """Test case for upload_mobile_app_source_map_file

        Upload sourcemap file for mobile app
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.snapshot_result import SnapshotResult

class TestSnapshotResult(unittest.TestCase):
    """SnapshotResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SnapshotResult:
        """Test SnapshotResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SnapshotResult`
        """
        model = SnapshotResult()
        if include_optional:
            return SnapshotResult(
                items = [
                    instana_client.models.snapshot_item.SnapshotItem(
                        data = {
                            'key' : None
                            }, 
                        from = 56, 
                        host = '', 
                        label = '', 
                        plugin = 'host', 
                        snapshot_id = '', 
                        tags = [
                            ''
                            ], 
                        to = 56, )
                    ]
            )
        else:
            return SnapshotResult(
        )
        """

    def testSnapshotResult(self):
        """Test SnapshotResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.cursor_pagination import CursorPagination
from instana_client.models.deprecated_tag_filter import DeprecatedTagFilter
from instana_client.models.mobile_app_beacon_tag_group import MobileAppBeaconTagGroup
from instana_client.models.mobile_app_monitoring_metrics_configuration import MobileAppMonitoringMetricsConfiguration
from instana_client.models.order import Order
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from instana_client.models.time_frame import TimeFrame
from typing import Optional, Set
from typing_extensions import Self

class GetMobileAppBeaconGroups(BaseModel):
    """
    GetMobileAppBeaconGroups
    """ # noqa: E501
    group: MobileAppBeaconTagGroup
    metrics: Annotated[List[MobileAppMonitoringMetricsConfiguration], Field(min_length=1, max_length=5)]
    order: Optional[Order] = None
    pagination: Optional[CursorPagination] = None
    tag_filter_expression: Optional[TagFilterExpressionElement] = Field(default=None, alias="tagFilterExpression")
    tag_filters: Optional[Annotated[List[DeprecatedTagFilter], Field(min_length=0, max_length=32)]] = Field(default=None, alias="tagFilters")
    time_frame: Optional[TimeFrame] = Field(default=None, alias="timeFrame")
    type: StrictStr
    __properties: ClassVar[List[str]] = ["group", "metrics", "order", "pagination", "tagFilterExpression", "tagFilters", "timeFrame", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['SESSION_START', 'HTTP_REQUEST', 'CRASH', 'CUSTOM', 'VIEW_CHANGE', 'DROP_BEACON', 'PERF']):
            raise ValueError("must be one of enum values ('SESSION_START', 'HTTP_REQUEST', 'CRASH', 'CUSTOM', 'VIEW_CHANGE', 'DROP_BEACON', 'PERF')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetMobileAppBeaconGroups from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of group
        if self.group:
            _dict['group'] = self.group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in metrics (list)
        _items = []
        if self.metrics:
            for _item_metrics in self.metrics:
                if _item_metrics:
                    _items.append(_item_metrics.to_dict())
            _dict['metrics'] = _items
        # override the default output from pydantic by calling `to_dict()` of order
        if self.order:
            _dict['order'] = self.order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict['pagination'] = self.pagination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tag_filter_expression
        if self.tag_filter_expression:
            _dict['tagFilterExpression'] = self.tag_filter_expression.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tag_filters (list)
        _items = []
        if self.tag_filters:
            for _item_tag_filters in self.tag_filters:
                if _item_tag_filters:
                    _items.append(_item_tag_filters.to_dict())
            _dict['tagFilters'] = _items
        # override the default output from pydantic by calling `to_dict()` of time_frame
        if self.time_frame:
            _dict['timeFrame'] = self.time_frame.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetMobileAppBeaconGroups from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "group": MobileAppBeaconTagGroup.from_dict(obj["group"]) if obj.get("group") is not None else None,
            "metrics": [MobileAppMonitoringMetricsConfiguration.from_dict(_item) for _item in obj["metrics"]] if obj.get("metrics") is not None else None,
            "order": Order.from_dict(obj["order"]) if obj.get("order") is not None else None,
            "pagination": CursorPagination.from_dict(obj["pagination"]) if obj.get("pagination") is not None else None,
            "tagFilterExpression": TagFilterExpressionElement.from_dict(obj["tagFilterExpression"]) if obj.get("tagFilterExpression") is not None else None,
            "tagFilters": [DeprecatedTagFilter.from_dict(_item) for _item in obj["tagFilters"]] if obj.get("tagFilters") is not None else None,
            "timeFrame": TimeFrame.from_dict(obj["timeFrame"]) if obj.get("timeFrame") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.metrics_test_result_item import MetricsTestResultItem
from typing import Optional, Set
from typing_extensions import Self

class MetricsResultItem(BaseModel):
    """
    MetricsResultItem
    """ # noqa: E501
    custom_tags: Optional[Dict[str, StrictStr]] = Field(default=None, description="A map of custom properties composed of the custom property name and its value.  This information will be included if the custom properties were requested or if the query was grouped and the grouping included one or more custom properties.", alias="customTags")
    metrics: List[Dict[str, Dict[str, Any]]] = Field(description="A map of the requested metrics, composed of the metric name and its value.")
    run_type: Optional[StrictStr] = Field(default=None, description="Indicates whether the test was scheduled to run or run now", alias="runType")
    tests: Optional[List[MetricsTestResultItem]] = Field(default=None, description="A description of the Synthetic test associated with the result item.  This information will be included if the request was grouped by synthetic.testId or if includeAggregatedTestId was true on the request.")
    __properties: ClassVar[List[str]] = ["customTags", "metrics", "runType", "tests"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetricsResultItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tests (list)
        _items = []
        if self.tests:
            for _item_tests in self.tests:
                if _item_tests:
                    _items.append(_item_tests.to_dict())
            _dict['tests'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetricsResultItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customTags": obj.get("customTags"),
            "metrics": obj.get("metrics"),
            "runType": obj.get("runType"),
            "tests": [MetricsTestResultItem.from_dict(_item) for _item in obj["tests"]] if obj.get("tests") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_trace_download_result_item import GetTraceDownloadResultItem

class TestGetTraceDownloadResultItem(unittest.TestCase):
    """GetTraceDownloadResultItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTraceDownloadResultItem:
        """Test GetTraceDownloadResultItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTraceDownloadResultItem`
        """
        model = GetTraceDownloadResultItem()
        if include_optional:
            return GetTraceDownloadResultItem(
                call_count = 56,
                cursor = instana_client.models.cursor.cursor(),
                destination = instana_client.models.call_relation.CallRelation(
                    endpoint = instana_client.models.endpoint_simple.EndpointSimple(
                        id = '', 
                        label = '', 
                        type = 'UNDEFINED', ), 
                    service = instana_client.models.service_simple.ServiceSimple(
                        id = '', 
                        label = '', ), 
                    technologies = [
                        ''
                        ], ),
                duration = 56,
                error_count = 56,
                foreign_parent_id = '',
                id = '',
                min_self_time = 56,
                name = '',
                network_time = 56,
                parent_id = '',
                timestamp = 56
            )
        else:
            return GetTraceDownloadResultItem(
        )
        """

    def testGetTraceDownloadResultItem(self):
        """Test GetTraceDownloadResultItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.abstract_rule import AbstractRule
from instana_client.models.action import Action
from typing import Optional, Set
from typing_extensions import Self

class CustomEventSpecificationWithLastUpdated(BaseModel):
    """
    CustomEventSpecificationWithLastUpdated
    """ # noqa: E501
    actions: Optional[List[Action]] = None
    application_alert_config_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, alias="applicationAlertConfigId")
    deleted: Optional[StrictBool] = None
    description: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=32765)]] = None
    enabled: Optional[StrictBool] = None
    entity_type: Annotated[str, Field(min_length=0, strict=True, max_length=64)] = Field(alias="entityType")
    expiration_time: Optional[StrictInt] = Field(default=None, alias="expirationTime")
    id: Annotated[str, Field(min_length=0, strict=True, max_length=64)]
    last_updated: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, alias="lastUpdated")
    migrated: Optional[StrictBool] = None
    name: Annotated[str, Field(min_length=0, strict=True, max_length=256)]
    query: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=2048)]] = None
    rule_logical_operator: Optional[StrictStr] = Field(default=None, description="Set AND / OR", alias="ruleLogicalOperator")
    rules: Annotated[List[AbstractRule], Field(min_length=1, max_length=5)]
    transient_event_alert_muted: Optional[StrictBool] = Field(default=None, alias="transientEventAlertMuted")
    transient_event_enabled: Optional[StrictBool] = Field(default=None, alias="transientEventEnabled")
    transient_event_threshold: Optional[StrictInt] = Field(default=None, alias="transientEventThreshold")
    triggering: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["actions", "applicationAlertConfigId", "deleted", "description", "enabled", "entityType", "expirationTime", "id", "lastUpdated", "migrated", "name", "query", "ruleLogicalOperator", "rules", "transientEventAlertMuted", "transientEventEnabled", "transientEventThreshold", "triggering"]

    @field_validator('rule_logical_operator')
    def rule_logical_operator_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['AND', 'OR']):
            raise ValueError("must be one of enum values ('AND', 'OR')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomEventSpecificationWithLastUpdated from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item_actions in self.actions:
                if _item_actions:
                    _items.append(_item_actions.to_dict())
            _dict['actions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in rules (list)
        _items = []
        if self.rules:
            for _item_rules in self.rules:
                if _item_rules:
                    _items.append(_item_rules.to_dict())
            _dict['rules'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomEventSpecificationWithLastUpdated from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actions": [Action.from_dict(_item) for _item in obj["actions"]] if obj.get("actions") is not None else None,
            "applicationAlertConfigId": obj.get("applicationAlertConfigId"),
            "deleted": obj.get("deleted"),
            "description": obj.get("description"),
            "enabled": obj.get("enabled"),
            "entityType": obj.get("entityType"),
            "expirationTime": obj.get("expirationTime"),
            "id": obj.get("id"),
            "lastUpdated": obj.get("lastUpdated"),
            "migrated": obj.get("migrated"),
            "name": obj.get("name"),
            "query": obj.get("query"),
            "ruleLogicalOperator": obj.get("ruleLogicalOperator"),
            "rules": [AbstractRule.from_dict(_item) for _item in obj["rules"]] if obj.get("rules") is not None else None,
            "transientEventAlertMuted": obj.get("transientEventAlertMuted"),
            "transientEventEnabled": obj.get("transientEventEnabled"),
            "transientEventThreshold": obj.get("transientEventThreshold"),
            "triggering": obj.get("triggering")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.api_group import ApiGroup

class TestApiGroup(unittest.TestCase):
    """ApiGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiGroup:
        """Test ApiGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiGroup`
        """
        model = ApiGroup()
        if include_optional:
            return ApiGroup(
                id = '',
                members = [
                    instana_client.models.api_member.ApiMember(
                        email = '', 
                        name = '', 
                        user_id = '', )
                    ],
                name = '',
                permission_set = instana_client.models.api_permission_set.ApiPermissionSet(
                    action_filter = instana_client.models.scope_binding.ScopeBinding(
                        scope_id = '', 
                        scope_role_id = '', ), 
                    application_ids = [
                        instana_client.models.scope_binding.ScopeBinding(
                            scope_id = '', 
                            scope_role_id = '', )
                        ], 
                    business_perspective_ids = [
                        
                        ], 
                    infra_dfq_filter = , 
                    kubernetes_cluster_uuids = [
                        
                        ], 
                    kubernetes_namespace_uids = [
                        
                        ], 
                    mobile_app_ids = [
                        
                        ], 
                    permissions = [
                        ''
                        ], 
                    restricted_application_filter = instana_client.models.api_restricted_application_filter.ApiRestrictedApplicationFilter(
                        label = '', 
                        restricting_application_id = '', 
                        scope = 'INCLUDE_NO_DOWNSTREAM', 
                        tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                            type = '', ), ), 
                    slo_ids = [
                        
                        ], 
                    synthetic_credential_keys = [
                        
                        ], 
                    synthetic_test_ids = [
                        
                        ], 
                    website_ids = [
                        
                        ], )
            )
        else:
            return ApiGroup(
                id = '',
                members = [
                    instana_client.models.api_member.ApiMember(
                        email = '', 
                        name = '', 
                        user_id = '', )
                    ],
                name = '',
                permission_set = instana_client.models.api_permission_set.ApiPermissionSet(
                    action_filter = instana_client.models.scope_binding.ScopeBinding(
                        scope_id = '', 
                        scope_role_id = '', ), 
                    application_ids = [
                        instana_client.models.scope_binding.ScopeBinding(
                            scope_id = '', 
                            scope_role_id = '', )
                        ], 
                    business_perspective_ids = [
                        
                        ], 
                    infra_dfq_filter = , 
                    kubernetes_cluster_uuids = [
                        
                        ], 
                    kubernetes_namespace_uids = [
                        
                        ], 
                    mobile_app_ids = [
                        
                        ], 
                    permissions = [
                        ''
                        ], 
                    restricted_application_filter = instana_client.models.api_restricted_application_filter.ApiRestrictedApplicationFilter(
                        label = '', 
                        restricting_application_id = '', 
                        scope = 'INCLUDE_NO_DOWNSTREAM', 
                        tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                            type = '', ), ), 
                    slo_ids = [
                        
                        ], 
                    synthetic_credential_keys = [
                        
                        ], 
                    synthetic_test_ids = [
                        
                        ], 
                    website_ids = [
                        
                        ], ),
        )
        """

    def testApiGroup(self):
        """Test ApiGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_test import SyntheticTest

class TestSyntheticTest(unittest.TestCase):
    """SyntheticTest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticTest:
        """Test SyntheticTest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticTest`
        """
        model = SyntheticTest()
        if include_optional:
            return SyntheticTest(
                active = True,
                application_id = '',
                application_label = '',
                application_labels = [
                    ''
                    ],
                applications = [
                    ''
                    ],
                configuration = instana_client.models.synthetic_type_configuration.SyntheticTypeConfiguration(
                    mark_synthetic_call = True, 
                    retries = 0, 
                    retry_interval = 1, 
                    synthetic_type = 'BrowserScript', 
                    timeout = '', ),
                created_at = 56,
                created_by = '',
                custom_properties = {
                    'key' : ''
                    },
                description = '',
                id = '0',
                label = '0',
                location_display_labels = [
                    ''
                    ],
                location_labels = [
                    ''
                    ],
                locations = [
                    ''
                    ],
                mobile_app_labels = [
                    ''
                    ],
                mobile_apps = [
                    ''
                    ],
                modified_at = 56,
                modified_by = '',
                playback_mode = 'Simultaneous',
                rbac_tags = [
                    instana_client.models.api_tag.ApiTag(
                        display_name = '', 
                        id = '', )
                    ],
                tenant_id = '',
                test_frequency = 1,
                website_labels = [
                    ''
                    ],
                websites = [
                    ''
                    ]
            )
        else:
            return SyntheticTest(
                active = True,
                configuration = instana_client.models.synthetic_type_configuration.SyntheticTypeConfiguration(
                    mark_synthetic_call = True, 
                    retries = 0, 
                    retry_interval = 1, 
                    synthetic_type = 'BrowserScript', 
                    timeout = '', ),
                label = '0',
                locations = [
                    ''
                    ],
                test_frequency = 1,
        )
        """

    def testSyntheticTest(self):
        """Test SyntheticTest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.action import Action

class TestAction(unittest.TestCase):
    """Action unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Action:
        """Test Action
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Action`
        """
        model = Action()
        if include_optional:
            return Action(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                fields = [
                    instana_client.models.field.Field(
                        description = '', 
                        encoding = '', 
                        name = '', 
                        secured = True, 
                        value = '', )
                    ],
                id = '0',
                input_parameters = [
                    instana_client.models.parameter.Parameter(
                        description = '', 
                        hidden = True, 
                        label = '', 
                        name = '', 
                        required = True, 
                        secured = True, 
                        type = '', 
                        value = '', )
                    ],
                metadata = instana_client.models.meta_data.MetaData(
                    ai = [
                        {
                            'key' : None
                            }
                        ], 
                    ai_originated = True, 
                    built_in = True, 
                    read_only = True, 
                    sensor_imported = True, ),
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '0',
                tags = [
                    ''
                    ],
                type = 'SCRIPT'
            )
        else:
            return Action(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '0',
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                name = '0',
                type = 'SCRIPT',
        )
        """

    def testAction(self):
        """Test Action"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_datacenter import SyntheticDatacenter

class TestSyntheticDatacenter(unittest.TestCase):
    """SyntheticDatacenter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticDatacenter:
        """Test SyntheticDatacenter
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticDatacenter`
        """
        model = SyntheticDatacenter()
        if include_optional:
            return SyntheticDatacenter(
                city_name = '',
                code = '0',
                configuration = instana_client.models.synthetic_datacenter_configuration.SyntheticDatacenterConfiguration(
                    ip_addresses = [
                        ''
                        ], ),
                country_name = '',
                datacenter_id = '',
                expected_active_at = 56,
                label = '0',
                latitude = 1.337,
                location_label = '',
                longitude = 1.337,
                modified_at = 56,
                provider = '0',
                status = ''
            )
        else:
            return SyntheticDatacenter(
                city_name = '',
                code = '0',
                country_name = '',
                label = '0',
                provider = '0',
        )
        """

    def testSyntheticDatacenter(self):
        """Test SyntheticDatacenter"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_result_list_item import TestResultListItem

class TestTestResultListItem(unittest.TestCase):
    """TestResultListItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResultListItem:
        """Test TestResultListItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResultListItem`
        """
        model = TestResultListItem()
        if include_optional:
            return TestResultListItem(
                metrics = {
                    'key' : [
                        [
                            1.337
                            ]
                        ]
                    },
                test_result_common_properties = instana_client.models.test_result_common_properties.TestResultCommonProperties(
                    client_id = '', 
                    custom_tags = {
                        'key' : ''
                        }, 
                    dns_query_type = '', 
                    dns_server_name = '', 
                    errors = [
                        ''
                        ], 
                    id = '', 
                    ism_details = {
                        'key' : ''
                        }, 
                    last_errors = instana_client.models.test_last_error.TestLastError(
                        start_time = 56, ), 
                    location_display_label = '', 
                    location_id = '', 
                    run_type = '', 
                    ssl_days_remaining = '', 
                    test_common_properties = instana_client.models.test_common_properties.TestCommonProperties(
                        active = True, 
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        application_label = '', 
                        application_labels = [
                            ''
                            ], 
                        created_at = 56, 
                        frequency = 56, 
                        get_website_labels = [
                            ''
                            ], 
                        id = '', 
                        label = '', 
                        location_display_labels = [
                            ''
                            ], 
                        location_ids = [
                            ''
                            ], 
                        location_labels = [
                            ''
                            ], 
                        location_status_list = [
                            instana_client.models.location_status.LocationStatus(
                                location_display_label = '', 
                                location_id = '', 
                                success_rate = 1.337, 
                                success_runs = 56, 
                                total_test_runs = 56, )
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        mobile_application_labels = [
                            ''
                            ], 
                        modified_at = 56, 
                        service_id = '', 
                        type = '', 
                        website_ids = [
                            ''
                            ], 
                        website_labels = [
                            ''
                            ], ), 
                    test_id = '', 
                    test_last_error = instana_client.models.test_last_error.TestLastError(
                        start_time = 56, ), 
                    test_name = '', )
            )
        else:
            return TestResultListItem(
                metrics = {
                    'key' : [
                        [
                            1.337
                            ]
                        ]
                    },
                test_result_common_properties = instana_client.models.test_result_common_properties.TestResultCommonProperties(
                    client_id = '', 
                    custom_tags = {
                        'key' : ''
                        }, 
                    dns_query_type = '', 
                    dns_server_name = '', 
                    errors = [
                        ''
                        ], 
                    id = '', 
                    ism_details = {
                        'key' : ''
                        }, 
                    last_errors = instana_client.models.test_last_error.TestLastError(
                        start_time = 56, ), 
                    location_display_label = '', 
                    location_id = '', 
                    run_type = '', 
                    ssl_days_remaining = '', 
                    test_common_properties = instana_client.models.test_common_properties.TestCommonProperties(
                        active = True, 
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        application_label = '', 
                        application_labels = [
                            ''
                            ], 
                        created_at = 56, 
                        frequency = 56, 
                        get_website_labels = [
                            ''
                            ], 
                        id = '', 
                        label = '', 
                        location_display_labels = [
                            ''
                            ], 
                        location_ids = [
                            ''
                            ], 
                        location_labels = [
                            ''
                            ], 
                        location_status_list = [
                            instana_client.models.location_status.LocationStatus(
                                location_display_label = '', 
                                location_id = '', 
                                success_rate = 1.337, 
                                success_runs = 56, 
                                total_test_runs = 56, )
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        mobile_application_labels = [
                            ''
                            ], 
                        modified_at = 56, 
                        service_id = '', 
                        type = '', 
                        website_ids = [
                            ''
                            ], 
                        website_labels = [
                            ''
                            ], ), 
                    test_id = '', 
                    test_last_error = instana_client.models.test_last_error.TestLastError(
                        start_time = 56, ), 
                    test_name = '', ),
        )
        """

    def testTestResultListItem(self):
        """Test TestResultListItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.event_filtering_configuration import EventFilteringConfiguration
from instana_client.models.static_string_field import StaticStringField
from typing import Optional, Set
from typing_extensions import Self

class AlertingConfigurationWithLastUpdated(BaseModel):
    """
    AlertingConfigurationWithLastUpdated
    """ # noqa: E501
    alert_name: Annotated[str, Field(min_length=0, strict=True, max_length=256)] = Field(description="Name of the Alert Configuration.", alias="alertName")
    custom_payload_fields: Annotated[List[StaticStringField], Field(min_length=0, max_length=20)] = Field(description="Custom payload fields to send additional information in the alert notifications. Can be left empty.", alias="customPayloadFields")
    event_filtering_configuration: EventFilteringConfiguration = Field(alias="eventFilteringConfiguration")
    id: Annotated[str, Field(min_length=0, strict=True, max_length=64)] = Field(description="ID of the Alert Configuration.")
    include_entity_name_in_legacy_alerts: Optional[StrictBool] = Field(default=None, description="To include the entity name in a legacy alert based on built-in/custom events.", alias="includeEntityNameInLegacyAlerts")
    integration_ids: Annotated[List[StrictStr], Field(min_length=0, max_length=1024)] = Field(description="List of Alert Channel IDs added in this Alert Configuration.", alias="integrationIds")
    last_updated: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Unix timestamp representing the time the configuration was last updated.", alias="lastUpdated")
    mute_until: Optional[StrictInt] = Field(default=None, description="Timer dictating how long the Alert Configuration will stay muted. A value of `0` means the Alert Configuration is currently enabled. Otherwise, the Alert Configuration is currently disabled (muted).", alias="muteUntil")
    __properties: ClassVar[List[str]] = ["alertName", "customPayloadFields", "eventFilteringConfiguration", "id", "includeEntityNameInLegacyAlerts", "integrationIds", "lastUpdated", "muteUntil"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlertingConfigurationWithLastUpdated from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in custom_payload_fields (list)
        _items = []
        if self.custom_payload_fields:
            for _item_custom_payload_fields in self.custom_payload_fields:
                if _item_custom_payload_fields:
                    _items.append(_item_custom_payload_fields.to_dict())
            _dict['customPayloadFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of event_filtering_configuration
        if self.event_filtering_configuration:
            _dict['eventFilteringConfiguration'] = self.event_filtering_configuration.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlertingConfigurationWithLastUpdated from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alertName": obj.get("alertName"),
            "customPayloadFields": [StaticStringField.from_dict(_item) for _item in obj["customPayloadFields"]] if obj.get("customPayloadFields") is not None else None,
            "eventFilteringConfiguration": EventFilteringConfiguration.from_dict(obj["eventFilteringConfiguration"]) if obj.get("eventFilteringConfiguration") is not None else None,
            "id": obj.get("id"),
            "includeEntityNameInLegacyAlerts": obj.get("includeEntityNameInLegacyAlerts"),
            "integrationIds": obj.get("integrationIds"),
            "lastUpdated": obj.get("lastUpdated"),
            "muteUntil": obj.get("muteUntil")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MetricsTestResultItem(BaseModel):
    """
    A description of the Synthetic test associated with the result item.  This information will be included if the request was grouped by synthetic.testId or if includeAggregatedTestId was true on the request.
    """ # noqa: E501
    application_id: Optional[StrictStr] = Field(default=None, description="An identifier of an application associated with the Synthetic test.  This field is deprecated and will be replace by the applicationIds field.", alias="applicationId")
    application_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of the applications associated with the Synthetic test.", alias="applicationIds")
    location_id: Optional[List[StrictStr]] = Field(default=None, description="A list of the locations associated with the Synthetic test.", alias="locationId")
    mobile_application_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of the mobile applications associated with the Synthetic test.", alias="mobileApplicationIds")
    service_id: Optional[StrictStr] = Field(default=None, description="A service associated with the Synthetic test.", alias="serviceId")
    test_id: StrictStr = Field(description="The testId for the Synthetic test.", alias="testId")
    test_name: Optional[StrictStr] = Field(default=None, description="The Synthetic test's name.", alias="testName")
    website_ids: Optional[List[StrictStr]] = Field(default=None, description="A list of the websites associated with the Synthetic test.", alias="websiteIds")
    __properties: ClassVar[List[str]] = ["applicationId", "applicationIds", "locationId", "mobileApplicationIds", "serviceId", "testId", "testName", "websiteIds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetricsTestResultItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetricsTestResultItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "applicationId": obj.get("applicationId"),
            "applicationIds": obj.get("applicationIds"),
            "locationId": obj.get("locationId"),
            "mobileApplicationIds": obj.get("mobileApplicationIds"),
            "serviceId": obj.get("serviceId"),
            "testId": obj.get("testId"),
            "testName": obj.get("testName"),
            "websiteIds": obj.get("websiteIds")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.service_matching_rule import ServiceMatchingRule
from typing import Optional, Set
from typing_extensions import Self

class ServiceConfig(BaseModel):
    """
    ServiceConfig
    """ # noqa: E501
    comment: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=2048)]] = Field(default=None, description="A small description of the service configuration would be present in this field if it was provided during creation of the custom service rule. If it was not provided, this field will remain empty. It is considered as best practice to add a comment to document the reasoning behind creating the rule. ")
    enabled: StrictBool = Field(description="If enabled, calls will be mapped to the rule.")
    id: StrictStr = Field(description="A unique string for the service configuration. Eg: `G510hmXYSDysLZ5kuj0BaQ`")
    label: StrictStr = Field(description="It contains the tags defined in `matchSpecification` concatenated with a dash. Eg: if the `matchSpecification` contains keys `kubernetes.namespace.name` and `docker.label`, `label` would be `kubernetes.namespace.name-docker.label`. ")
    match_specification: Annotated[List[ServiceMatchingRule], Field(min_length=0, max_length=20)] = Field(description="Calls will be matched with the array of key-value tags present in this field.", alias="matchSpecification")
    name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="The name of the service configuration. Eg: `Rule ABC`")
    __properties: ClassVar[List[str]] = ["comment", "enabled", "id", "label", "matchSpecification", "name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in match_specification (list)
        _items = []
        if self.match_specification:
            for _item_match_specification in self.match_specification:
                if _item_match_specification:
                    _items.append(_item_match_specification.to_dict())
            _dict['matchSpecification'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "comment": obj.get("comment"),
            "enabled": obj.get("enabled"),
            "id": obj.get("id"),
            "label": obj.get("label"),
            "matchSpecification": [ServiceMatchingRule.from_dict(_item) for _item in obj["matchSpecification"]] if obj.get("matchSpecification") is not None else None,
            "name": obj.get("name")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_test_update import SyntheticTestUpdate

class TestSyntheticTestUpdate(unittest.TestCase):
    """SyntheticTestUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticTestUpdate:
        """Test SyntheticTestUpdate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticTestUpdate`
        """
        model = SyntheticTestUpdate()
        if include_optional:
            return SyntheticTestUpdate(
                active = True,
                applications = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                custom_properties = instana_client.models.synthetic_resource_update_map_string_string_list_string.SyntheticResourceUpdateMapStringStringListString(
                    add = {
                        'key' : ''
                        }, 
                    remove = [
                        ''
                        ], ),
                ids = [
                    ''
                    ],
                last_modified_at = [
                    56
                    ],
                locations = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                mobile_apps = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], ),
                modified_by = '',
                shallow_update = True,
                synthetic_update_type = 'Deep',
                test_frequency = 1,
                websites = instana_client.models.synthetic_resource_update_list_string_list_string.SyntheticResourceUpdateListStringListString(
                    add = [
                        ''
                        ], 
                    remove = [
                        ''
                        ], )
            )
        else:
            return SyntheticTestUpdate(
                synthetic_update_type = 'Deep',
        )
        """

    def testSyntheticTestUpdate(self):
        """Test SyntheticTestUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.graph_node import GraphNode

class TestGraphNode(unittest.TestCase):
    """GraphNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GraphNode:
        """Test GraphNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GraphNode`
        """
        model = GraphNode()
        if include_optional:
            return GraphNode(
                data = {
                    'key' : None
                    },
                entity_id = instana_client.models.entity_id.EntityId(
                    host = '', 
                    plugin_id = '', 
                    steady_id = '', ),
                id = '',
                label = '',
                plugin = ''
            )
        else:
            return GraphNode(
        )
        """

    def testGraphNode(self):
        """Test GraphNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class WebsiteBeaconGroupsItem(BaseModel):
    """
    Represents an array of call group item containing several attributes that describe its properties. The item includes fields such as cursor, metrics, name, and timestamp, which provide detailed information about the item. 
    """ # noqa: E501
    cursor: Dict[str, Any] = Field(description="Cursor to use between successive queries")
    earliest_timestamp: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, alias="earliestTimestamp")
    metrics: Dict[str, List[List[Union[StrictFloat, StrictInt]]]]
    name: StrictStr
    __properties: ClassVar[List[str]] = ["cursor", "earliestTimestamp", "metrics", "name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WebsiteBeaconGroupsItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WebsiteBeaconGroupsItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cursor": obj.get("cursor"),
            "earliestTimestamp": obj.get("earliestTimestamp"),
            "metrics": obj.get("metrics"),
            "name": obj.get("name")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_resource_update_list_ssl_certificate_validation_list_ssl_certificate_validation import SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation

class TestSyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(unittest.TestCase):
    """SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation:
        """Test SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation`
        """
        model = SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation()
        if include_optional:
            return SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(
                add = [
                    instana_client.models.ssl_certificate_validation.SSLCertificateValidation(
                        key = '', 
                        operator = 'CONTAINS', 
                        value = instana_client.models.value.value(), )
                    ],
                remove = [
                    instana_client.models.ssl_certificate_validation.SSLCertificateValidation(
                        key = '', 
                        operator = 'CONTAINS', 
                        value = instana_client.models.value.value(), )
                    ]
            )
        else:
            return SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(
        )
        """

    def testSyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation(self):
        """Test SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.infrastructure_item import InfrastructureItem

class TestInfrastructureItem(unittest.TestCase):
    """InfrastructureItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InfrastructureItem:
        """Test InfrastructureItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InfrastructureItem`
        """
        model = InfrastructureItem()
        if include_optional:
            return InfrastructureItem(
                entity_health_info = instana_client.models.entity_health_info.EntityHealthInfo(
                    max_severity = 0, 
                    open_issues = [
                        instana_client.models.event.Event(
                            end = 1, 
                            endpoint_service_id = '', 
                            entity_id = '', 
                            entity_type = 'Entity10', 
                            event_configuration_type = '', 
                            id = '', 
                            long_form_plugin_id = '', 
                            metadata = {
                                'key' : None
                                }, 
                            metric_access_id = '', 
                            plugin = '', 
                            problem = instana_client.models.problem.Problem(
                                fix_suggestion = '', 
                                id = '', 
                                problem_text = '', 
                                severity = 56, ), 
                            rca = {
                                'key' : None
                                }, 
                            start = 1, 
                            state = '', 
                            type = '', )
                        ], ),
                label = '',
                metrics = {
                    'key' : [
                        [
                            1.337
                            ]
                        ]
                    },
                plugin = '',
                snapshot_id = '',
                tags = {
                    'key' : ''
                    },
                time = 56
            )
        else:
            return InfrastructureItem(
        )
        """

    def testInfrastructureItem(self):
        """Test InfrastructureItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class SloReport(BaseModel):
    """
    SloReport
    """ # noqa: E501
    error_accumulation_chart: Optional[Dict[str, StrictInt]] = Field(default=None, description="Value of accumulated bad minutes/events of SLO configuration in different timestamps from starting to ending point", alias="errorAccumulationChart")
    error_budget_remain_chart: Optional[Dict[str, StrictInt]] = Field(default=None, description="Error Budget Remain value of SLO configuration in different timestamps from starting to ending point", alias="errorBudgetRemainChart")
    error_budget_remaining: Optional[StrictInt] = Field(default=None, description="Latest Remaining Error Budget value of SLO Configuration", alias="errorBudgetRemaining")
    error_budget_spent: Optional[StrictInt] = Field(default=None, description="Spent Error Budget of SLO Configuration", alias="errorBudgetSpent")
    error_burn_rate: Optional[StrictInt] = Field(default=None, description="Latest Burn Rate value of SLO Configuration", alias="errorBurnRate")
    error_burn_rate_chart: Optional[Dict[str, StrictInt]] = Field(default=None, description="Budget Rate value of SLO configuration in different timestamps from starting to ending point", alias="errorBurnRateChart")
    error_chart: Optional[Dict[str, StrictInt]] = Field(default=None, description="Value indicating presence of bad minutes/events of SLO configuration in different timestamps from starting to ending point", alias="errorChart")
    from_timestamp: Optional[StrictInt] = Field(default=None, description="Starting point of the data retrieval, specified as 13 digit Unix Timestamp milliseconds", alias="fromTimestamp")
    sli: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Latest Status value of SLO Configuration")
    slo: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Target status of SLO Configuration")
    to_timestamp: Optional[StrictInt] = Field(default=None, description="Ending point of the data retrieval, specified as 13 digit Unix Timestamp milliseconds", alias="toTimestamp")
    total_error_budget: Optional[StrictInt] = Field(default=None, description="Latest Available Error Budget value of SLO Configuration", alias="totalErrorBudget")
    violation_distribution: Optional[Dict[str, StrictInt]] = Field(default=None, description="Value indicating violation of SLO configuration in different timestamps from starting to ending point", alias="violationDistribution")
    __properties: ClassVar[List[str]] = ["errorAccumulationChart", "errorBudgetRemainChart", "errorBudgetRemaining", "errorBudgetSpent", "errorBurnRate", "errorBurnRateChart", "errorChart", "fromTimestamp", "sli", "slo", "toTimestamp", "totalErrorBudget", "violationDistribution"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SloReport from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SloReport from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "errorAccumulationChart": obj.get("errorAccumulationChart"),
            "errorBudgetRemainChart": obj.get("errorBudgetRemainChart"),
            "errorBudgetRemaining": obj.get("errorBudgetRemaining"),
            "errorBudgetSpent": obj.get("errorBudgetSpent"),
            "errorBurnRate": obj.get("errorBurnRate"),
            "errorBurnRateChart": obj.get("errorBurnRateChart"),
            "errorChart": obj.get("errorChart"),
            "fromTimestamp": obj.get("fromTimestamp"),
            "sli": obj.get("sli"),
            "slo": obj.get("slo"),
            "toTimestamp": obj.get("toTimestamp"),
            "totalErrorBudget": obj.get("totalErrorBudget"),
            "violationDistribution": obj.get("violationDistribution")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.synthetic_resource_update_list_string_list_string import SyntheticResourceUpdateListStringListString
from instana_client.models.synthetic_resource_update_map_string_string_list_string import SyntheticResourceUpdateMapStringStringListString
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from instana_client.models.synthetic_test_deep_update import SyntheticTestDeepUpdate
    from instana_client.models.synthetic_test_shallow_update import SyntheticTestShallowUpdate

class SyntheticTestUpdate(BaseModel):
    """
    Identifies the type of the synthetic tests updated on this request. Valid types are Deep and Shallow.
    """ # noqa: E501
    active: Optional[StrictBool] = None
    applications: Optional[SyntheticResourceUpdateListStringListString] = None
    custom_properties: Optional[SyntheticResourceUpdateMapStringStringListString] = Field(default=None, alias="customProperties")
    ids: Optional[List[StrictStr]] = None
    last_modified_at: Optional[List[StrictInt]] = Field(default=None, alias="lastModifiedAt")
    locations: Optional[SyntheticResourceUpdateListStringListString] = None
    mobile_apps: Optional[SyntheticResourceUpdateListStringListString] = Field(default=None, alias="mobileApps")
    modified_by: Optional[StrictStr] = Field(default=None, alias="modifiedBy")
    shallow_update: Optional[StrictBool] = Field(default=None, alias="shallowUpdate")
    synthetic_update_type: StrictStr = Field(description="Indicates the type of update to apply to a set of tests of same syntheticType (Deep) or a mix of syntheticType values (Shallow). When Shallow is used, only the configuration properties retries, retryInterval and timeout can be updated ", alias="syntheticUpdateType")
    test_frequency: Optional[Annotated[int, Field(le=1440, strict=True, ge=1)]] = Field(default=None, alias="testFrequency")
    websites: Optional[SyntheticResourceUpdateListStringListString] = None
    __properties: ClassVar[List[str]] = ["active", "applications", "customProperties", "ids", "lastModifiedAt", "locations", "mobileApps", "modifiedBy", "shallowUpdate", "syntheticUpdateType", "testFrequency", "websites"]

    @field_validator('synthetic_update_type')
    def synthetic_update_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Deep', 'Shallow']):
            raise ValueError("must be one of enum values ('Deep', 'Shallow')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'syntheticUpdateType'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        'Deep': 'SyntheticTestDeepUpdate','Shallow': 'SyntheticTestShallowUpdate'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[SyntheticTestDeepUpdate, SyntheticTestShallowUpdate]]:
        """Create an instance of SyntheticTestUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of applications
        if self.applications:
            _dict['applications'] = self.applications.to_dict()
        # override the default output from pydantic by calling `to_dict()` of custom_properties
        if self.custom_properties:
            _dict['customProperties'] = self.custom_properties.to_dict()
        # override the default output from pydantic by calling `to_dict()` of locations
        if self.locations:
            _dict['locations'] = self.locations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mobile_apps
        if self.mobile_apps:
            _dict['mobileApps'] = self.mobile_apps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of websites
        if self.websites:
            _dict['websites'] = self.websites.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[SyntheticTestDeepUpdate, SyntheticTestShallowUpdate]]:
        """Create an instance of SyntheticTestUpdate from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type ==  'SyntheticTestDeepUpdate':
            return import_module("instana_client.models.synthetic_test_deep_update").SyntheticTestDeepUpdate.from_dict(obj)
        if object_type ==  'SyntheticTestShallowUpdate':
            return import_module("instana_client.models.synthetic_test_shallow_update").SyntheticTestShallowUpdate.from_dict(obj)

        raise ValueError("SyntheticTestUpdate failed to lookup discriminator value from " +
                            json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                            ", mapping: " + json.dumps(cls.__discriminator_value_class_map))





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.mobile_app_monitoring_beacon import MobileAppMonitoringBeacon

class TestMobileAppMonitoringBeacon(unittest.TestCase):
    """MobileAppMonitoringBeacon unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MobileAppMonitoringBeacon:
        """Test MobileAppMonitoringBeacon
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MobileAppMonitoringBeacon`
        """
        model = MobileAppMonitoringBeacon()
        if include_optional:
            return MobileAppMonitoringBeacon(
                accuracy_radius = -1,
                agent_version = '',
                app_build = '',
                app_version = '',
                app_version_number = -1,
                available_mb = -1,
                backend_trace_id = '',
                batch_size = 1,
                beacon_id = '',
                bundle_identifier = '',
                bytes_ingested = 56,
                carrier = '',
                city = '',
                clock_skew = 0,
                cold_start_time_ms = -1,
                connection_type = '',
                continent = '',
                continent_code = '',
                country = '',
                country_code = '',
                current_app_state = '',
                custom_event_name = '',
                custom_metric = 1.337,
                decoded_body_size = -1,
                device_hardware = '',
                device_manufacturer = '',
                device_model = '',
                drop_view = '',
                duration = 0,
                effective_connection_type = '',
                encoded_body_size = -1,
                environment = '',
                error_count = 0,
                error_id = '',
                error_message = '',
                error_type = '',
                google_play_services_missing = True,
                hot_start_time_ms = -1,
                http_call_headers = {
                    'key' : ''
                    },
                http_call_method = '',
                http_call_origin = '',
                http_call_path = '',
                http_call_status = -1,
                http_call_url = '',
                ingestion_time = 1,
                internal_meta = {
                    'key' : ''
                    },
                label = '',
                latitude = 1.337,
                longitude = 1.337,
                max_mb = -1,
                meta = {
                    'key' : ''
                    },
                mobile_app_id = '',
                mobile_app_label = '',
                os_name = '',
                os_version = '',
                parent_beacon_id = '',
                parsed_stack_trace = '',
                performance_subtype = '',
                platform = '',
                rate_limit_beacon_type = '',
                rate_limit_count = 0,
                rate_limit_custom_metric_val = [
                    1.337
                    ],
                rate_limit_time_max = 0,
                rate_limit_time_min = 0,
                region = '',
                rooted = True,
                session_id = '',
                stack_trace = '',
                stack_trace_key_checksum = '',
                stack_trace_key_information = '',
                stack_trace_line = [
                    instana_client.models.stack_trace_line.StackTraceLine(
                        column = -1, 
                        file = '', 
                        line = -1, 
                        name = '', 
                        translation_explanation = '', 
                        translation_status = -1, )
                    ],
                stack_trace_parsing_status = -1,
                subdivision = '',
                subdivision_code = '',
                tenant = '',
                timestamp = 1,
                transfer_size = -1,
                type = '',
                unit = '',
                use_features = [
                    ''
                    ],
                used_mb = -1,
                user_email = '',
                user_id = '',
                user_ip = '',
                user_languages = [
                    ''
                    ],
                user_name = '',
                user_session_id = '',
                view = '',
                viewport_height = -1,
                viewport_width = -1,
                warm_start_time_ms = -1
            )
        else:
            return MobileAppMonitoringBeacon(
                beacon_id = '',
                mobile_app_id = '',
                performance_subtype = '',
                rate_limit_beacon_type = '',
                type = '',
        )
        """

    def testMobileAppMonitoringBeacon(self):
        """Test MobileAppMonitoringBeacon"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class CursorPagination(BaseModel):
    """
    Details for controlling the pagination of the API response. This object allows you to define the starting point for retrieving records, how many records to skip, and the size of the result set. 
    """ # noqa: E501
    ingestion_time: Optional[StrictInt] = Field(default=None, description="The timestamp indicating the starting point from which data was ingested. The format of the timestamp is in Unix epoch Time. For example, `Thursday, 5 September 2024 07:03:13 GMT` can be represented as `1725519793`. ", alias="ingestionTime")
    offset: Optional[StrictInt] = Field(default=None, description="The number of records to be skipped from the `ingestionTime`. For example: when `offset` is 20 and `ingestionTime` is 1725519793, the API response should have records starting from the 21st record after the specified `ingestionTime`. Note that if `offset` value is not empty, `ingestionTime` can't be empty. ")
    retrieval_size: Optional[Annotated[int, Field(le=200, strict=True, ge=1)]] = Field(default=None, description="The number of records to retrieve in a single request. For example, when retrievalSize is set to 30, offset is 20, and ingestionTime is 1725519793, the API request will fetch 30 records starting from the 21st record after the specified `ingestionTime`. Minimum value is 1 and maximum value is 200. ", alias="retrievalSize")
    __properties: ClassVar[List[str]] = ["ingestionTime", "offset", "retrievalSize"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CursorPagination from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CursorPagination from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ingestionTime": obj.get("ingestionTime"),
            "offset": obj.get("offset"),
            "retrievalSize": obj.get("retrievalSize")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.log_volume_usage_result import LogVolumeUsageResult

class TestLogVolumeUsageResult(unittest.TestCase):
    """LogVolumeUsageResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogVolumeUsageResult:
        """Test LogVolumeUsageResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogVolumeUsageResult`
        """
        model = LogVolumeUsageResult()
        if include_optional:
            return LogVolumeUsageResult(
                log_volume_usage_items = [
                    instana_client.models.log_volume_usage_item.LogVolumeUsageItem(
                        log_volume = 56, 
                        number_of_month = 1, 
                        retention_periods = [
                            instana_client.models.retention_period.RetentionPeriod(
                                log_volume = 56, 
                                log_volume_groups = [
                                    instana_client.models.log_volume_group.LogVolumeGroup(
                                        label = '', 
                                        log_volume = 56, )
                                    ], 
                                retention_days = 7, )
                            ], )
                    ]
            )
        else:
            return LogVolumeUsageResult(
                log_volume_usage_items = [
                    instana_client.models.log_volume_usage_item.LogVolumeUsageItem(
                        log_volume = 56, 
                        number_of_month = 1, 
                        retention_periods = [
                            instana_client.models.retention_period.RetentionPeriod(
                                log_volume = 56, 
                                log_volume_groups = [
                                    instana_client.models.log_volume_group.LogVolumeGroup(
                                        label = '', 
                                        log_volume = 56, )
                                    ], 
                                retention_days = 7, )
                            ], )
                    ],
        )
        """

    def testLogVolumeUsageResult(self):
        """Test LogVolumeUsageResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.authentication_api import AuthenticationApi


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_delete_google_sso_config(self) -> None:
        """Test case for delete_google_sso_config

        Delete Google SSO configuration
        """
        pass

    def test_delete_ldap_config(self) -> None:
        """Test case for delete_ldap_config

        Delete LDAP configuration
        """
        pass

    def test_delete_oidc_config(self) -> None:
        """Test case for delete_oidc_config

        Delete OIDC configuration
        """
        pass

    def test_delete_saml_config(self) -> None:
        """Test case for delete_saml_config

        Delete SAML configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace_groups_result import TraceGroupsResult

class TestTraceGroupsResult(unittest.TestCase):
    """TraceGroupsResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TraceGroupsResult:
        """Test TraceGroupsResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceGroupsResult`
        """
        model = TraceGroupsResult()
        if include_optional:
            return TraceGroupsResult(
                adjusted_timeframe = instana_client.models.adjusted_timeframe.AdjustedTimeframe(
                    to = 56, 
                    window_size = 0, ),
                can_load_more = True,
                items = [
                    instana_client.models.trace_groups_item.TraceGroupsItem(
                        cursor = instana_client.models.cursor.cursor(), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, 
                        name = '', 
                        timestamp = 0, )
                    ],
                total_hits = 0,
                total_represented_item_count = 0,
                total_retained_item_count = 0
            )
        else:
            return TraceGroupsResult(
                items = [
                    instana_client.models.trace_groups_item.TraceGroupsItem(
                        cursor = instana_client.models.cursor.cursor(), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, 
                        name = '', 
                        timestamp = 0, )
                    ],
        )
        """

    def testTraceGroupsResult(self):
        """Test TraceGroupsResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_bulk_response import SyntheticBulkResponse

class TestSyntheticBulkResponse(unittest.TestCase):
    """SyntheticBulkResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticBulkResponse:
        """Test SyntheticBulkResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticBulkResponse`
        """
        model = SyntheticBulkResponse()
        if include_optional:
            return SyntheticBulkResponse(
                error_message = '',
                id = '',
                status = ''
            )
        else:
            return SyntheticBulkResponse(
        )
        """

    def testSyntheticBulkResponse(self):
        """Test SyntheticBulkResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class AccessRule(BaseModel):
    """
    AccessRule
    """ # noqa: E501
    access_type: StrictStr = Field(description="Specifies the type of access permitted.   `READ`: Only viewing Application Perspective is allowed.   `READ_WRITE`: Both viewing and modifying Application Perspective are permitted.   ", alias="accessType")
    related_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, description="An identifier that connects the access rule to a specific entity. For example, if the `relationType` is `USER`, the corresponding `relatedId` would be a user id.   **Note**: when `relationType` is `GLOBAL`, `relatedId` is `null`. ", alias="relatedId")
    relation_type: StrictStr = Field(description="Defines the type of relationship or subject to which the access rule applies.   `USER`: Access is granted to an individual user.   `API_TOKEN`: Access is granted to a specific API token.   `ROLE`: Access is granted based on a user role, applying to any user with that role.   `TEAM`: Access is granted to a team, likely applying to all team members.   `GLOBAL`: Access is granted to every user or service. ", alias="relationType")
    __properties: ClassVar[List[str]] = ["accessType", "relatedId", "relationType"]

    @field_validator('access_type')
    def access_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['READ', 'READ_WRITE']):
            raise ValueError("must be one of enum values ('READ', 'READ_WRITE')")
        return value

    @field_validator('relation_type')
    def relation_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['USER', 'API_TOKEN', 'ROLE', 'TEAM', 'GLOBAL']):
            raise ValueError("must be one of enum values ('USER', 'API_TOKEN', 'ROLE', 'TEAM', 'GLOBAL')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessRule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessRule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessType": obj.get("accessType"),
            "relatedId": obj.get("relatedId"),
            "relationType": obj.get("relationType")
        })
        return _obj


